==> vue-create-web-0.1.0.tgz: package/es/components/controls/echarts/LineChart.js <==
import "core-js/modules/es.function.name.js";
import "core-js/modules/es.object.keys.js";
import _classCallCheck from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createClass";
import _inherits from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/inherits";
import _createSuper from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createSuper";
import { __decorate } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mixins } from 'vue-class-component';
import BaseChart from './BaseChart';
import { withInstall } from '@/util';
var xAxisData = ['13:00', '13:05', '13:10', '13:15', '13:20', '13:25', '13:30', '13:35', '13:40', '13:45', '13:50', '13:55'];
var data = {
  CMCC: [220, 182, 191, 134, 150, 120, 110, 125, 145, 122, 165, 122],
  CTCC: [120, 110, 125, 145, 122, 165, 122, 220, 182, 191, 134, 150],
  CUCC: [220, 182, 125, 145, 122, 191, 134, 150, 120, 110, 165, 122]
};
export var defaultData = {
  xAxisData: xAxisData,
  data: data
};
export var defaultOption = {
  backgroundColor: '#394056',
  title: {
    top: 20,
    text: 'Requests',
    textStyle: {
      fontWeight: 'normal',
      fontSize: 16,
      color: '#F1F1F3'
    },
    left: '1%'
  },
  tooltip: {
    trigger: 'axis'
  },
  legend: {
    top: 20,
    icon: 'rect',
    itemWidth: 14,
    itemHeight: 5,
    itemGap: 13,
    data: Object.keys(data),
    right: '4%',
    textStyle: {
      fontSize: 12,
      color: '#F1F1F3'
    }
  },
  grid: {
    top: 100,
    left: '2%',
    right: '2%',
    bottom: '2%',
    containLabel: true
  },
  xAxis: [{
    type: 'category',
    boundaryGap: false,
    axisLine: {
      lineStyle: {
        color: '#57617B'
      }
    },
    data: xAxisData
  }],
  yAxis: [{
    type: 'value',
    name: '(%)',
    axisTick: {
      show: false
    },
    axisLine: {
      lineStyle: {
        color: '#57617B'
      }
    },
    axisLabel: {
      margin: 10,
      fontSize: 14
    },
    splitLine: {
      lineStyle: {
        color: '#57617B'
      }
    }
  }],
  series: [{
    name: Object.keys(data)[0],
    type: 'line',
    smooth: true,
    symbol: 'circle',
    symbolSize: 5,
    showSymbol: false,
    lineStyle: {
      width: 1
    },
    areaStyle: {
      type: 'linear',
      x: 0,
      y: 0,
      x2: 0,
      y2: 1,
      colorStops: [{
        offset: 0,
        color: 'rgba(137, 189, 27, 0.3)'
      }, {
        offset: 0.8,
        color: 'rgba(137, 189, 27, 0)'
      }],
      shadowColor: 'rgba(0, 0, 0, 0.1)',
      shadowBlur: 10
    },
    itemStyle: {
      color: 'rgb(137,189,27)',
      borderColor: 'rgba(137,189,2,0.27)',
      borderWidth: 12
    },
    data: data[Object.keys(data)[0]]
  }, {
    name: Object.keys(data)[1],
    type: 'line',
    smooth: true,
    symbol: 'circle',
    symbolSize: 5,
    showSymbol: false,
    lineStyle: {
      width: 1
    },
    areaStyle: {
      type: 'linear',
      x: 0,
      y: 0,
      x2: 0,
      y2: 1,
      colorStops: [{
        offset: 0,
        color: 'rgba(0, 136, 212, 0.3)'
      }, {
        offset: 0.8,
        color: 'rgba(0, 136, 212, 0)'
      }],
      shadowColor: 'rgba(0, 0, 0, 0.1)',
      shadowBlur: 10
    },
    itemStyle: {
      color: 'rgb(0,136,212)',
      borderColor: 'rgba(0,136,212,0.2)',
      borderWidth: 12
    },
    data: data[Object.keys(data)[1]]
  }, {
    name: Object.keys(data)[2],
    type: 'line',
    smooth: true,
    symbol: 'circle',
    symbolSize: 5,
    showSymbol: false,
    lineStyle: {
      width: 1
    },
    areaStyle: {
      type: 'linear',
      x: 0,
      y: 0,
      x2: 0,
      y2: 1,
      colorStops: [{
        offset: 0,
        color: 'rgba(219, 50, 51, 0.3)'
      }, {
        offset: 0.8,
        color: 'rgba(219, 50, 51, 0)'
      }],
      shadowColor: 'rgba(0, 0, 0, 0.1)',
      shadowBlur: 10
    },
    itemStyle: {
      color: 'rgb(219,50,51)',
      borderColor: 'rgba(219,50,51,0.2)',
      borderWidth: 12
    },
    data: data[Object.keys(data)[2]]
  }]
};

var LineChart = /*#__PURE__*/function (_mixins) {
  _inherits(LineChart, _mixins);

  var _super = _createSuper(LineChart);

  function LineChart() {
    _classCallCheck(this, LineChart);

    return _super.apply(this, arguments);
  }

  _createClass(LineChart, [{
    key: "mounted",
    value: function mounted() {}
  }, {
    key: "options",
    get: function get() {
      if (this.chartOption.legend) {
        this.chartOption.legend['data'] = Object.keys(this.chartData.data);
      }

      if (this.chartOption.xAxis) {
        this.chartOption.xAxis[0].data = this.chartData.xAxisData;
      }

      if (this.chartOption.series && Array.isArray(this.chartOption.series)) {
        this.chartOption.series[0] && (this.chartOption.series[0].name = Object.keys(this.chartData.data)[0], this.chartOption.series[0].data = this.chartData.data[Object.keys(this.chartData.data)[0]]);
        this.chartOption.series[1] && (this.chartOption.series[1].name = Object.keys(this.chartData.data)[1], this.chartOption.series[1].data = this.chartData.data[Object.keys(this.chartData.data)[1]]);
        this.chartOption.series[2] && (this.chartOption.series[2].name = Object.keys(this.chartData.data)[2], this.chartOption.series[2].data = this.chartData.data[Object.keys(this.chartData.data)[2]]);
      }

      return this.chartOption;
    }
  }]);

  return LineChart;
}(mixins(BaseChart));

__decorate([Prop({
  default: function _default() {
    return defaultData;
  }
})], LineChart.prototype, "chartData", void 0);

__decorate([Prop({
  default: function _default() {
    return defaultOption;
  }
})], LineChart.prototype, "chartOption", void 0);

LineChart = __decorate([Component({
  name: 'LineChart',
  categrey: 'echart图表',
  zhName: '拆线图',
  iconType: 'line-chart'
})], LineChart);
export default withInstall(LineChart);

==> vue-create-web-0.1.2.tgz: package/es/components/controls/echarts/LineChart.js <==
import "core-js/modules/es.function.name.js";
import "core-js/modules/es.object.keys.js";
import _classCallCheck from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createClass";
import _inherits from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/inherits";
import _createSuper from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createSuper";
import { __decorate } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mixins } from 'vue-class-component';
import BaseChart from './BaseChart';
import { withInstall } from '../../../util';
var xAxisData = ['13:00', '13:05', '13:10', '13:15', '13:20', '13:25', '13:30', '13:35', '13:40', '13:45', '13:50', '13:55'];
var data = {
  CMCC: [220, 182, 191, 134, 150, 120, 110, 125, 145, 122, 165, 122],
  CTCC: [120, 110, 125, 145, 122, 165, 122, 220, 182, 191, 134, 150],
  CUCC: [220, 182, 125, 145, 122, 191, 134, 150, 120, 110, 165, 122]
};
export var defaultData = {
  xAxisData: xAxisData,
  data: data
};
export var defaultOption = {
  backgroundColor: '#394056',
  title: {
    top: 20,
    text: 'Requests',
    textStyle: {
      fontWeight: 'normal',
      fontSize: 16,
      color: '#F1F1F3'
    },
    left: '1%'
  },
  tooltip: {
    trigger: 'axis'
  },
  legend: {
    top: 20,
    icon: 'rect',
    itemWidth: 14,
    itemHeight: 5,
    itemGap: 13,
    data: Object.keys(data),
    right: '4%',
    textStyle: {
      fontSize: 12,
      color: '#F1F1F3'
    }
  },
  grid: {
    top: 100,
    left: '2%',
    right: '2%',
    bottom: '2%',
    containLabel: true
  },
  xAxis: [{
    type: 'category',
    boundaryGap: false,
    axisLine: {
      lineStyle: {
        color: '#57617B'
      }
    },
    data: xAxisData
  }],
  yAxis: [{
    type: 'value',
    name: '(%)',
    axisTick: {
      show: false
    },
    axisLine: {
      lineStyle: {
        color: '#57617B'
      }
    },
    axisLabel: {
      margin: 10,
      fontSize: 14
    },
    splitLine: {
      lineStyle: {
        color: '#57617B'
      }
    }
  }],
  series: [{
    name: Object.keys(data)[0],
    type: 'line',
    smooth: true,
    symbol: 'circle',
    symbolSize: 5,
    showSymbol: false,
    lineStyle: {
      width: 1
    },
    areaStyle: {
      type: 'linear',
      x: 0,
      y: 0,
      x2: 0,
      y2: 1,
      colorStops: [{
        offset: 0,
        color: 'rgba(137, 189, 27, 0.3)'
      }, {
        offset: 0.8,
        color: 'rgba(137, 189, 27, 0)'
      }],
      shadowColor: 'rgba(0, 0, 0, 0.1)',
      shadowBlur: 10
    },
    itemStyle: {
      color: 'rgb(137,189,27)',
      borderColor: 'rgba(137,189,2,0.27)',
      borderWidth: 12
    },
    data: data[Object.keys(data)[0]]
  }, {
    name: Object.keys(data)[1],
    type: 'line',
    smooth: true,
    symbol: 'circle',
    symbolSize: 5,
    showSymbol: false,
    lineStyle: {
      width: 1
    },
    areaStyle: {
      type: 'linear',
      x: 0,
      y: 0,
      x2: 0,
      y2: 1,
      colorStops: [{
        offset: 0,
        color: 'rgba(0, 136, 212, 0.3)'
      }, {
        offset: 0.8,
        color: 'rgba(0, 136, 212, 0)'
      }],
      shadowColor: 'rgba(0, 0, 0, 0.1)',
      shadowBlur: 10
    },
    itemStyle: {
      color: 'rgb(0,136,212)',
      borderColor: 'rgba(0,136,212,0.2)',
      borderWidth: 12
    },
    data: data[Object.keys(data)[1]]
  }, {
    name: Object.keys(data)[2],
    type: 'line',
    smooth: true,
    symbol: 'circle',
    symbolSize: 5,
    showSymbol: false,
    lineStyle: {
      width: 1
    },
    areaStyle: {
      type: 'linear',
      x: 0,
      y: 0,
      x2: 0,
      y2: 1,
      colorStops: [{
        offset: 0,
        color: 'rgba(219, 50, 51, 0.3)'
      }, {
        offset: 0.8,
        color: 'rgba(219, 50, 51, 0)'
      }],
      shadowColor: 'rgba(0, 0, 0, 0.1)',
      shadowBlur: 10
    },
    itemStyle: {
      color: 'rgb(219,50,51)',
      borderColor: 'rgba(219,50,51,0.2)',
      borderWidth: 12
    },
    data: data[Object.keys(data)[2]]
  }]
};

var LineChart = /*#__PURE__*/function (_mixins) {
  _inherits(LineChart, _mixins);

  var _super = _createSuper(LineChart);

  function LineChart() {
    _classCallCheck(this, LineChart);

    return _super.apply(this, arguments);
  }

  _createClass(LineChart, [{
    key: "mounted",
    value: function mounted() {}
  }, {
    key: "options",
    get: function get() {
      if (this.chartOption.legend) {
        this.chartOption.legend['data'] = Object.keys(this.chartData.data);
      }

      if (this.chartOption.xAxis) {
        this.chartOption.xAxis[0].data = this.chartData.xAxisData;
      }

      if (this.chartOption.series && Array.isArray(this.chartOption.series)) {
        this.chartOption.series[0] && (this.chartOption.series[0].name = Object.keys(this.chartData.data)[0], this.chartOption.series[0].data = this.chartData.data[Object.keys(this.chartData.data)[0]]);
        this.chartOption.series[1] && (this.chartOption.series[1].name = Object.keys(this.chartData.data)[1], this.chartOption.series[1].data = this.chartData.data[Object.keys(this.chartData.data)[1]]);
        this.chartOption.series[2] && (this.chartOption.series[2].name = Object.keys(this.chartData.data)[2], this.chartOption.series[2].data = this.chartData.data[Object.keys(this.chartData.data)[2]]);
      }

      return this.chartOption;
    }
  }]);

  return LineChart;
}(mixins(BaseChart));

__decorate([Prop({
  default: function _default() {
    return defaultData;
  }
})], LineChart.prototype, "chartData", void 0);

__decorate([Prop({
  default: function _default() {
    return defaultOption;
  }
})], LineChart.prototype, "chartOption", void 0);

LineChart = __decorate([Component({
  name: 'LineChart',
  categrey: 'echart图表',
  zhName: '拆线图',
  iconType: 'line-chart'
})], LineChart);
export default withInstall(LineChart);
